
<script setup name="Post">
import { areaApi} from "@/api/area/index";
import {region} from "@/api/basicApi/index.js";
import { onMounted } from "vue";
import user from "@/api/system/user.js";
import setPostParams from "@/utils/searchParams.js";
const { proxy } = getCurrentInstance();

const loading = ref(true); //加载状态

/** 区域table相关 */
const tableData = ref([]); //区域列表
const total = ref(0);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
let  tableHeader = ref({

    areaName: '区域名称',
    // regionName: '省市区域',
    areaUserName: '区域负责人',
    address:'详细地址',
    statusName: '状态',
    updateTimeView: '更新时间',
})
//获取列表数据
const getList = async(val) => {

    loading.value = true;
    let postParam = setPostParams(val)
    let res = await areaApi().search(postParam)
    if(res.code == 200) {
        loading.value = false;
        tableData.value = res.data.list;

        total.value = res.data.total;
        search.page = res.data.page;
        search.limit = res.data.limit;
    }
}


/**
 * 表单相关
 */
const openForm = ref(false);
const title = ref("");
const data = reactive({
    //表单
    form: {
        areaGrade:'',
        parentAreaId:'',
        areaName:'',
        region:'',
        regionName:'',
        areaUser:'',
        areaUserName:'',
        address:'',
        remark:'',
        status:true,
    },
    //查询数据
    search: {
        page: 1, //当前页
        limit: 10, //每页条数
        areaName: '',
        status: ''
    },
    //表单验证
    rules: {
        areaName: [{ required: true, message: "请输入区域名称", trigger: "blur" }],
        address: [{ required: true, message: "请输入详细地址", trigger: "blur" }],
        areaUser: [{ required: true, message: "请选择区域负责人", trigger: "blur" }],
        name:[{ required: false, message: "请选择省市区域", trigger: "blur" }],
    },
});
const { search, form, rules } = toRefs(data);

/**
 * select列表数据
 */
//获取管网父级区域列表
const parentAreaList = ref([])
const getParentArea = async()=>{
    let res = await areaApi().getTree('')
    parentAreaList.value = res.data
}
const changeParentTree = (e)=>{
    // form.value.parentAreaId = e.id
    form.value.areaGrade = e.areaGrade
    console.log('e001',e)
}


//省市区域列表
const regionTreeList =  ref([])
//获取省市区域列表
const getRegionList = async() =>{
    let res = await region().search('')
    if(res.code == 200) {
        res.data.forEach((item)=>{
            if(item.children == null){
                item.children = [{}]
            }
        })
        regionTreeList.value = res.data
    }
}
//展开所属区域树形， 请求展开区域的下一层子级数据
const expandTree = async (data) => {
    //请求展开区域的下一层子级列表数据
    let res = await region().search(data.code)
    if(res.code == 200) {
        res.data.forEach((item)=>{
            if((item.children == null) && item.level!=4){
                item.children = [{}]
            }
        })
        data.children =  res.data
    }
}
//选中区域
const changeTreeValue = (_, nodeData) => {

    form.value.region = getTreeCode(nodeData, 'code').join(',')
    nextTick(()=>{
        form.value.regionName = getTreeCode(nodeData, 'name').join(',')
    })
}
//从当前选择区域树形查找父级code，组装为[123,456,789](xx省/xx市/xx区)
const getTreeCode = (tree, type) => {

    let codeList = []
    if(tree.data.level!=1){
        codeList = codeList.concat(getTreeCode(tree.parent, type))
        codeList.push(tree.data[type])
    }else{
        return [tree.data[type]]
    }
    return codeList
}

//获取管理员列表
const areaUserList =ref([])
const getUserList = async() =>{

    loading.value = true;
    let res = await user().search({limit:100,page:1})
    if(res.code == 200) {
        loading.value = false;
        areaUserList.value = res.data.list
    }
}
async function changeUserList(e){

    console.log('areauser',e)
    areaUserList.value.forEach((item =>{
        if(item.id == e){
            form.value.areaUserName = item.nickName
        }
    }))
}

/** 提交表单按钮 */
function submitForm() {

    proxy.$refs["postRef"].validate(async valid => {
        if (valid) {
            if(!form.value.id){
                console.log('form.value000',form.value)
                form.value.status = form.value.status ? 1: 0
                let res = await areaApi().create(form.value)
                if(res.code == 200) {
                    proxy.$modal.msgSuccess("添加成功")
                    openForm.value = false
                    getList()
                    reset()
                }else{
                    proxy.$modal.msgError("添加失败")
                    openForm.value = false
                    reset()
                }
            }else{
                form.value.status = form.value.status ? 1: 0
                let res = await areaApi().modify(form.value)
                if(res.code == 200) {
                    proxy.$modal.msgSuccess("修改成功")
                    openForm.value = false
                    getList()
                    reset()
                }else{
                    proxy.$modal.msgError("修改失败")
                    openForm.value = false
                    reset()
                }
            }
        }
    });
}

/**
 * 操作相关
 */

/** 搜索按钮操作 */
function handleQuery() {
    getList({keywords:search.value.areaName});
}
/** 重置按钮操作 */
function resetQuery() {
    proxy.resetForm("queryRef");
    handleQuery();
}
/** 多选框选中数据 */
function handleSelectionChange(selection) {
    ids.value = selection.map(item => item.id);
    single.value = selection.length != 1;
    multiple.value = !selection.length;
}
/** 新增按钮操作 */
function handleAdd() {
    getParentArea()
    reset();
    openForm.value = true;
    title.value = "添加区域";
}
/** 修改按钮操作 */
function handleUpdate(row) {
    reset();
    //将表单数据更新为table对应值
    Object.keys(row).forEach(key => {
        if (form.value.hasOwnProperty(key)) {
            form.value[key] = row[key];
        }
    });
    form.value.id = row.id
    form.value.areaUser = Number(form.value.areaUser)
    console.log('form',form.value);
    openForm.value = true;
    title.value = "修改区域";
}

/** 删除按钮操作 */
function handleDelete(row) {
    proxy.$modal.confirm('确认删除"' + row.areaName +'？')
        .then(async() => {
            console.log("无删除功能");
            let res = await areaApi().remove(row.id)
            if(res.code == 200) {
                proxy.$modal.msgSuccess("删除成功");
                openForm.value = false
                getList()
            }
        }).catch(() => {});
}

/** 关闭弹窗 */
function cancel() {
    openForm.value = false;
    reset();
}
/** 表单重置 */
const reset = () => {
    proxy.resetForm("postRef");
    openForm.value = false
}
onMounted(async()=>{

    getList();
    getRegionList()
    getUserList()
    getParentArea()
})


</script>
<template>
    <div class="app-container">
        <!--搜索框-->
        <el-form :model="search" ref="queryRef" :inline="true">
            <el-form-item label="" prop="areaName">
                <el-input
                        v-model="search.areaName"
                        placeholder="请输入区域名称"
                        clearable
                        style="width: 200px"
                        @keyup.enter="handleQuery"
                />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
                <el-button icon="Refresh" @click="resetQuery">重置</el-button>

            </el-form-item>
        </el-form>
        <!--操作按钮列-->
        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                        type="primary"
                        plain
                        icon="Plus"
                        @click="handleAdd"
                >新增</el-button>
            </el-col>
        </el-row>

        <!--表格及分页-->
        <el-table v-loading="loading" :data="tableData" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align ="center" />
            <el-table-column
                    v-for="(item, key, index) of tableHeader"
                    :prop="key.toString()"
                    :label="item"
                    :key="index"
                    align="center"
            ></el-table-column>
            <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
                <template #default="scope">
                    <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
                    <el-button link type="danger" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
                </template>
            </el-table-column>
        </el-table>
        <pagination
                v-show="total > 0"
                :total="total"
                v-model:page="search.page"
                v-model:limit="search.limit"
                @pagination="getList"
        />
        <!-- 添加/修改弹窗 -->
        <el-dialog :title="title" v-model="openForm" width="45vw" center append-to-body>
            <el-form class="form-box" ref="postRef" :model="form" :rules="rules">
                <el-form-item label="父级区域" prop="parentAreaId">
                    <el-tree-select
                            v-model="form.parentAreaId"
                            :data="parentAreaList"
                            clearable
                            :props="{label:'areaName', value:'id'}"
                            placeholder="请选择区域"
                            highlight-current
                            @current-change="changeParentTree"
                            :check-strictly="true"
                    />
                </el-form-item>
                <el-form-item label="行政区域"  prop="regionName">
                    <el-tree-select
                            v-model="form.regionName"
                            :data="regionTreeList"
                            :props="{label:'name', value:'code'}"
                            placeholder="请选择区域"
                            filterable
                            highlight-current
                            :check-strictly="true"
                            @node-expand="expandTree"
                            @current-change="changeTreeValue"
                    />
                </el-form-item>
                <el-form-item label="区域负责人" prop="areaUser">
                    <el-select v-model="form.areaUser" placeholder="请输入负责人名称" @change="changeUserList">
                        <el-option
                                v-for="item in areaUserList"
                                :key="item.id"
                                :label="item.nickName"
                                :title="item.nickName"
                                :value="item.id"
                        />
                    </el-select>
                </el-form-item>
                <el-form-item label="区域名称" prop="areaName">
                    <el-input v-model="form.areaName" placeholder="请输入区域名称" />
                </el-form-item>
                <el-form-item label="详细地址" prop="address">
                    <el-input v-model="form.address" placeholder="请输入详细地址" />
                </el-form-item>
                <el-form-item label="状态" prop="status">
                    <el-switch v-model="form.status"/>
                </el-form-item>
                <el-form-item label="备注" prop="remark">
                    <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
                </el-form-item>
                <el-form-item></el-form-item>
            </el-form>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="submitForm">确 定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>
<style scoped lang="scss">
</style>